<?php
/*
Plugin Name: WP-Memory-Usage
Plugin URI: https://www.json-content-importer.com
Description: Show up memory limits, current memory usage, IP-Address, PHP-Version in the dashboard and admin footer
Author: Bernhard Kux
Version: 1.2.5
Author URI: https://www.json-content-importer.com
Text Domain: wp-memory-usage
Domain Path: /languages/
License: GPLv3
License URI: http://www.gnu.org/licenses/gpl-3.0.html

Copyright 2009-2013 by Alex Rabe, 2022- by Bernhard Kux 
*/

/* block direct requests */
if ( !function_exists( 'add_action' ) ) {
	echo 'Hello, this is a plugin: You must not call me directly.';
	exit;
}
defined('ABSPATH') OR exit;

if ( is_admin() ) {	

	define( 'WPMEMORYUSAGEVERSION', '1.2.5' ); // current version number
	
	function wp_memory_usage_i18n_init() {
		$pd = dirname(
			plugin_basename(__FILE__)
		).'/languages/';
		
		$id = "wp-memory-usage";
		
#		$loaderrorlevel = load_plugin_textdomain('wp-memory-usage', false, $pd);
		$loaderrorlevel = load_plugin_textdomain($id, false, $pd);
		
		$mof = WP_PLUGIN_DIR."/$pd/$id"."_de_DE.mo";
		if (file_exists($mof)) {
	
		} else {
		
		}
		
		if ($loaderrorlevel) {
		
		} else {
		
		}
	
	}
	add_action('plugins_loaded', 'wp_memory_usage_i18n_init');

	class wp_memory_usage {
		private $ipadr = "";
		private $servername = "";
		private $memory = array();	
		
		public function __construct() {
			$this->get_ip_adress();
            add_action( 'init', array (&$this, 'check_limit') );
			add_action( 'wp_dashboard_setup', array (&$this, 'add_dashboard') );
			if ( is_multisite() ) { 
				add_action( 'wp_network_dashboard_setup', array (&$this, 'add_dashboard') );
			}
			add_filter( 'admin_footer_text', array (&$this, 'add_footer') );
		}
        
        public function check_limit() {
			$this->memory['phplimit'] = "";
			$this->memory['phplimitunity'] = 'MB';
			if (!is_null(ini_get('memory_limit'))) {
				$this->memory['phplimit'] = (int) ini_get('memory_limit');
			}
			$ret = $this->formatWP_MEMORY_LIMIT(WP_MEMORY_LIMIT);
			$this->memory["wpmb"] = $ret["mb"];
			$this->memory["wpunity"] = $ret["unity"];
			
			$ret = $this->formatWP_MEMORY_LIMIT(WP_MAX_MEMORY_LIMIT);
			$this->memory["wpmaxmb"] = $ret["mb"];
			$this->memory["wpmaxunity"] = $ret["unity"];
        }
		
		private function check_memory_usage() {
			$this->memory['usage'] = function_exists('memory_get_peak_usage') ? round(memory_get_peak_usage(true) / 1024 / 1024, 2) : 0;
			if ( !empty($this->memory['usage'])) {
				$this->memory['percent'] = -1;
				if (!empty($this->memory['wpmb']) && ($this->memory['wpmb']!=0)) {
					$this->memory['percent'] = round($this->memory['usage'] /$this->memory["wpmb"] * 100, 0);
				}
				
				$this->memory['percentphp'] = -1;
				if (!empty($this->memory['phplimit']) && ($this->memory['phplimit']!=0)) {
					$this->memory['percentphp'] = round ($this->memory['usage'] / $this->memory["phplimit"] * 100, 0);
				}
				
				//If the bar is tp small we move the text outside
                $this->memory['percent_pos'] = '';
                //In case we are in our limits take the admin color 
                $this->memory['color'] = '';
				if ($this->memory['percent'] > 80) $this->memory['color'] = 'background: #E66F00;';
				if ($this->memory['percent'] > 95) $this->memory['color'] = 'background: red;';
                if ($this->memory['percent'] < 10) $this->memory['percent_pos'] = 'margin-right: -30px; color: #444;';
				$this->memory['percentwidth'] = $this->memory['percent'];
				if ($this->memory['percent']>100) {
					$this->memory['percentwidth'] = 100;
				}
			}		
		}
		
		public function dashboard_output() {
			$this->check_memory_usage();
			?>
				<ul>	
					<li><strong><?php echo __('PHP Version', 'wp_memory_usage'); ?>:</strong> <span><?php 
						echo PHP_VERSION; ?>&nbsp;/&nbsp;<?php echo (PHP_INT_SIZE * 8) . __('Bit OS', 'wp_memory_usage'); 
						
						if (!is_null(ini_get('max_execution_time'))) {
							$max_execution_time = (int) ini_get('max_execution_time'). __('sec', 'wp_memory_usage');
							echo " / ".__('Max execution time: ', 'wp_memory_usage').$max_execution_time;
						}
						
						
						?></span></li>
					<li><strong><?php echo __('Memory limits', 'wp_memory_usage'); ?></strong> : <span>
					<?php 
						if ($this->memory["wpmb"]!="") {
							echo __('Wordpress', 'wp_memory_usage').' '.$this->memory["wpmb"]. $this->memory["wpunity"]." / "; 
						}
						#if ($this->memory["wpmaxmb"]!="") {
						#	echo __('Wordpress-Admin', 'wp_memory_usage').' '.$this->memory["wpmaxmb"]. $this->memory["wpmaxunity"]." / "; 
						#}
						if ($this->memory['phplimit']!="") {
							echo __('PHP ', 'wp_memory_usage').' '.$this->memory['phplimit'].$this->memory['phplimitunity'];
						}
					?>
					</span></li>
					<li><strong><?php echo __('Memory usage', 'wp_memory_usage'); ?></strong> : <span><?php echo $this->memory['usage']."MB"; ?>
										<!--&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<?PHP #echo "<strong>".__( 'IP-Address', 'wp_memory_usage') . " " . $this->servername. ':</strong> '.$this->ipadr; ?>-->
					</span></li>
				</ul>
				<?php if (!empty($this->memory['percent'])) : ?>
				<div class="progressbar">
					<div style="border:1px solid #DDDDDD; background-color:#F9F9F9;	border-color: rgb(223, 223, 223); box-shadow: 0px 1px 0px rgb(255, 255, 255) inset; border-radius: 3px;">
                        <div class="button-primary" style="width: <?php echo $this->memory['percentwidth']; ?>%;<?php echo $this->memory['color'];?>padding: 0px;border-width:0px; color:#FFFFFF;text-align:right; border-color: rgb(223, 223, 223); box-shadow: 0px 1px 0px rgb(255, 255, 255) inset; border-radius: 3px; margin-top: -1px;">
							<div style="padding:2px;<?php echo $this->memory['percent_pos']; ?>"><?php echo $this->memory['percent']; ?>%</div>
						</div>
					</div>
				</div>
				<?php endif; ?>
			<?php
		}
		 
		public function add_dashboard() {
			$servertime = date("j.M Y, H:i:s");
			wp_add_dashboard_widget( 'wp_memory_dashboard', __('Memory Overview', 'wp_memory_usage')." / ".__('Servertime', 'wp_memory_usage').": ".$servertime, array (&$this, 'dashboard_output') );
		}
		
		private function formatWP_MEMORY_LIMIT($valin) { #WP_MEMORY_LIMIT and WP_MAX_MEMORY_LIMIT come with size and unity
			$size  = strtolower(substr($valin, -1));
	       	$number = (int) substr($valin, 0, -1);
			$ret = Array();
			if ($size=="k") { $ret["mb"] = ($number/1024); $ret["unity"] = "kB"; }
			if ($size=="m") { $ret["mb"] = $number; $ret["unity"] = "MB"; }
			if ($size=="g") { $ret["mb"] = ($number*1024); $ret["unity"] = "GB"; }
			if ($size=="t") { $ret["mb"] = ($number*(1024*1024)); $ret["unity"] = "TB"; }
			if ($size=="p") { $ret["mb"] = ($number*(1024*1024*1024)); $ret["unity"] = "PB"; }
			return $ret;
		}

		private function get_ip_adress() {
			if (isset($_SERVER[ 'SERVER_ADDR' ]) && !empty($_SERVER[ 'SERVER_ADDR' ])) {
				$this->ipadr = $_SERVER[ 'SERVER_ADDR' ];
			}
			if (empty($this->ipadr) && isset($_SERVER[ 'LOCAL_ADDR' ]) && !empty($_SERVER[ 'LOCAL_ADDR' ])) {
				$this->ipadr = $_SERVER[ 'LOCAL_ADDR' ];
			}
			
			if (!empty($_SERVER['SERVER_NAME'])) {
				$this->servername = " (".$_SERVER['SERVER_NAME'].")";
			}
		}

		public function add_footer($content) {
			$this->check_memory_usage();
			$content .= ' | '. __( 'WP Memory Limit:', 'wp_memory_usage'). ' ' . $this->memory['usage'] . ' ' . __( 'of', 'wp_memory_usage') . ' ' . $this->memory["wpmb"].$this->memory["wpunity"]. " (".$this->memory['percent']."%)";
			$content .= ' | '. __( 'PHP Memory Limit:', 'wp_memory_usage'). ' ' . $this->memory['usage'] . ' ' . __( 'of', 'wp_memory_usage') . ' ' . $this->memory['phplimit'].$this->memory['phplimitunity']. " (".$this->memory['percentphp']."%)";
			$content .= ' | '. __( 'IP-Address', 'wp_memory_usage') . " " . $this->servername. ': '.$this->ipadr;
			$content .= ' | '. __( 'PHP', 'wp_memory_usage') . ": " . PHP_VERSION;
			return $content;
		}

	}

	// Start this plugin once all other plugins are fully loaded
    function WP_Memory_Usage_action_plugins_loaded( $array ) { 
		return new wp_memory_usage();
    }; 
    add_action( 'plugins_loaded', 'WP_Memory_Usage_action_plugins_loaded', 10, 1 ); 	
}